@@ -144,6 +144,18 @@ def read_delta_stream(spark_session: SparkSession, spark_job_conf: dict, source_
         .load(source_stream_conf["location"])
 
 
+def write_delta(spark_job_conf: dict, output_name: str, df: DataFrame):
+    output_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
+    create_delta_tables_if_not_exists(output_conf, output_conf['delta_options']['schema'])
+    (
+        df
+        .write
+        .format("delta")
+        .mode(output_conf['delta_options']['mode'])
+        .save(output_conf['delta_options']['location'])
+    )
+
+
 def write_delta_stream(spark_job_conf: dict, output_name: str, stream: DataFrame):
     output_stream_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(output_stream_conf, output_stream_conf['delta_options']['schema'])
